%=============================================================
% Uma introduo  modelagem quase-esttica de automveis
% Captulo 6 - Diagramas de desempenho
% Exemplo pgina 137 da edio de Fevereiro de 2012
%=============================================================
clear all
close all
clc
%-------------------------------------------------------------------------
% dados do veculo
%-------------------------------------------------------------------------
% relaes das marchas
ic=[2.909; 1.9776; 1.471; 1.0];
% relao do diferencial
id=3.091;
% rendimento da transmisso
etam=0.90;
% dados dos pneus
rd=0.32;        % raio dinmico (m)
escorr=0.02;    % escorregamento
f=0.015;        % coeficiente de atrito de rolamento
% carroceria
A=2.0;          % rea frontal (m^2)
Cx=0.42;
% peso do veculo (N)
G=16503;
% presso atmosfrica (mmHg)
patm=760;    
% temperatura ambiente (K)
Tamb=15+273.15;
% densidade do ar
ro=0.4647*patm/Tamb;
% aclive
alfa=0*pi/180;
% nmero de pontos nos grficos
NP=20;
%% curva de potncia do motor
% rotao (rpm)
%nrpm=[1500;  2000;  2500;  3000;  3500;   4000;   4500;   5000;   5500;   6000];
nrpm=linspace(1500,6000,NP);
% potncia (W)
%PeWtab= [5560; 33100; 57500; 78500; 96000; 110100; 120800; 128000; 131800; 132100];
PeW=10^(-11)*nrpm.^4-1.7*10^(-7)*nrpm.^3-0.0058*(nrpm.^2)+77*nrpm-96000;
%% clculo do torque (N.m)
T=PeW./(2*pi*nrpm/60);
%%
% acelerao da gravidade (m/s^2)
grav=9.81;
% nmero de marchas
NM=size(ic,1);
%-------------------------------------------------------------------------
%% clculo das curvas de desempenho
%-------------------------------------------------------------------------
for j=1:NM
    for i=1:NP
        % velocidade tangencial
        vt(i,j)=2*pi/60*nrpm(i)/(ic(j)*id)*rd;
        % velocidade real
        vr(i,j)=vt(i,j)*(1-escorr);
        % resistncia aerodinmica
        Qa(i,j)=1/2*ro*vr(i,j)^2*A*Cx;
        % resistncia ao rolamento
        Qr(i,j)=f*G*cos(alfa);
        % resistncia ao aclive
        Qs(i,j)=G*sin(alfa);
        % potncia no cubo
        Pc(i,j)=PeW(i)*etam;
        % potncia consumida
        Pcons(i,j)=(Qa(i,j)+Qr(i,j)+Qs(i,j))*vt(i,j);
        % potncia lquida
        PL(i,j)=Pc(i,j)-Pcons(i,j);
    end
end
%-------------------------------------------------------------------------
%% captura dos parmetros
%-------------------------------------------------------------------------
%% aclives mximos
maxPLvr=max(PL./vr);
alfamax = asin(maxPLvr*(1-escorr)/G);
aclivemax = tan(alfamax)*100;
%% acelerao mxima
% inrcia equivalente
delta=0.004+0.05*ic.^2;
% acelerao mxima em cada marcha
acelmax=maxPLvr*(1-escorr)./(1+delta)'/G*grav;
acelmaxG=acelmax/grav;
%% velocidades limites
vrmin=vr(1,:);
vrmax=vr(end,:);

%-------------------------------------------------------------------------
%% grfico de torque e potncia do motor
%-------------------------------------------------------------------------
figure('name','Torque e potncia do motor')
[AX,H1,H2] = plotyy(nrpm,T,nrpm,PeW);
set(get(AX(1),'Ylabel'),'String','T (Nm)') 
set(get(AX(2),'Ylabel'),'String','Pe (W)') 
set(H1,'LineStyle',':')
set(H2,'LineStyle','--')
set(H1,'LineWidth',2)
set(H2,'LineWidth',2)
grid on
xlabel('n (rpm)')
%-------------------------------------------------------------------------
%% grfico das potncias no cubo e perdida
%-------------------------------------------------------------------------
figure('Name','Potncias no cubo e consumida')    % ttulo na moldura superior
plot(vr*3.6,Pc,'LineWidth',2)      
hold on
plot(vr*3.6,Pcons,'k','LineWidth',2)   
grid on                           % linhas de grade
xlabel('v (km/h)')                  % rtulo do eixo x
ylabel('P (W)')               % rtulo do eixo y
title('Potncia no cubo e potncia consumida')         % ttulo do grfico
xlim([0 Inf])                           % limites mnimo e mximo do eixo x
ylim([0 Inf])                       % limites mnimo e mximo do eixo y
legend('P_c 1^a marcha',...                 % legenda identificadora de cada marcha
       'P_c 2^a marcha',...
       'P_c 3^a marcha',...
       'P_c 4^a marcha',...
       'P_{cons}',4)
%-------------------------------------------------------------------------
%% grfico da potncia lquida
%-------------------------------------------------------------------------
figure('Name','Potncia lquida')    % ttulo na moldura superior
plot(vr*3.6,PL,'LineWidth',2)        
grid on                           % linhas de grade
xlabel('v (km/h)')                  % rtulo do eixo x
ylabel('P_L (W)')               % rtulo do eixo y
title('Potncia lquida')         % ttulo do grfico
legend('1^a marcha',...                 % legenda identificadora de cada marcha
       '2^a marcha',...
       '3^a marcha',...
       '4^a marcha',1)
hold on
plot(vr*3.6,PL,'ok','LineWidth',1)
%-------------------------------------------------------------------------
%% grfico das relaes da caixa
%-------------------------------------------------------------------------
figure('Name','Relaes')
plot(vr(:,1)*3.6,nrpm,vr(:,2)*3.6,nrpm,vr(:,3)*3.6,nrpm,vr(:,4)*3.6,nrpm,...
    'LineWidth',2)
axis([0 inf 0 inf])
xlabel('v (km/h')
ylabel('n (rpm)')
legend('1^a','2^a','3^a','4^a',4)
grid on
title('Relaes da caixa')
% ======================================================================== 
%% === F I M ===
% ========================================================================


