clear all
close all
clc
%% dados de entrada
grav=9.81;  % acelerao da gravidade
x=0.48;     % posio horizontal do CG
mu=0.8;     % coeficiente de atrito do pneu com a pista
f=0.011;    % coeficiente de atrito de rolamento
h=0.66;     % altura do CG vazio
l=2.4;      % distncia entre eixos
G=16503;    % peso vazio
rd=0.32;    % raio dinmico do pneu
Ddisco=0.25;    % dimetro do disco
rfI=0.1;        % raio da pina
rfII=0.1;
mupastilha=0.45;    % coeficiente de atrito da pastilha com o disco
pHid=2.45*10^6;     % presso na linha

Fpemax=1200;    % fora mxima no p
Ypedal=0.5;     % Ypedal=Lb/Lp
Lp=0.25;        % altura do p (m)
Lb=Ypedal*Lp;   % altura do acionamento (m)
%--------------------------------------------------------------
Y=0.5;      % distribuio da carga X=yf/yb
yb=0.2;     % comprimento do balancim (m)
Dmf=0.035;  % dimetro do cilindro mestre (m)
Dmr=0.035;
ncf=4;      % nmero de pistes na pina
ncr=4;
Dcf=0.04;   % dimetro do cilindro da pina
Dcr=0.04;
mucf=0.45;  % coeficiente de atrito da pastilha no disco
mucr=0.45;
Ddf=0.3;    % dimetro do disco
Ddr=0.3;
dof=0.05;   % posio do cilindro da pina a partir da borda do disco
dor=0.05;
Dtf=0.55;   % dimetro do pneu
Dtr=0.55;

%% ndice de frenagem
csi=((1-x)+(mu+f)*h/l)/(x-(mu+f)*h/l);
%% fora total de frenagem
Ff=mu*G;
%% reaes normais ao solo
RI=G*((1-x)+(mu+f)*h/l);
RII=G*(x-(mu+f)*h/l);
%% foras de frenagem
FfI=mu*RI;
FfII=mu*RII;
% verificao
%Ff-(FfI+FfII);
%% fora da pastilha sobre o disco
FdI=1/2*FfI*rd/rfI;
FdII=1/2*FfII*rd/rfII;
%% rea dos cilindros nas pinas
AI=FdI/(pHid*mupastilha);
AII=FdII/(pHid*mupastilha);
%% dimetro dos pistes
dpI=sqrt(4*AI/pi/4);
dpII=sqrt(4*AII/pi/4);
% verificao
%AI/AII-csi;
%% foras limite em funo da acelerao
acel=linspace(0,10,11);
FfImax=(1-x)*G*mu+G/grav*acel*mu*h/l;
FfIImax=x*G*mu-G/grav*acel*mu*h/l;
%% foras limite (retas)
ffI=linspace(0,FfI,10);
FfIIlim=mu*(G*x-ffI*h/l)/(1+mu*h/l);
ffII=linspace(0,FfII,10);
FfIlim=mu*(G*(1-x)+ffII*h/l)/(1-mu*h/l);
%% projeto do freio
Fpe=linspace(0,Fpemax,11);
yf=Y*yb;
yr=yb-yf;
Fbias=Fpe*Lp/Lb;
Fmf=Fbias*yr/yb;
Fmr=Fbias*yf/yb;
Pf=4*Fmf/(pi*Dmf^2);
Pr=4*Fmr/(pi*Dmr^2);
Fcf=Pf*pi*Dcf^2/4*ncf;
Fcr=Pr*pi*Dcr^2/4*ncr;
Faf=mucf*Fcf;
Far=mucr*Fcr;
Fff=Faf*(Ddf/2-dof)*2/Dtf*2;
Ffr=Far*(Ddr/2-dor)*2/Dtr*2;
teta=Fff/Ffr;

%% resultados
fprintf('mu  = %10.4f\n',mu)
fprintf('Ff   = %10.2f N\n',Ff)
fprintf('RI   = %10.2f N\n',RI)
fprintf('RII  = %10.2f N\n',RII)
fprintf('FfI  = %10.2f N\n',FfI)
fprintf('FfII = %10.2f N\n',FfII)
fprintf('FdI  = %10.2f N\n',FdI)
fprintf('FdII = %10.2f N\n',FdII)
fprintf('pHid = %10.2f MPa\n',pHid*10^(-6))
fprintf('AI   = %10.2f mm^2\n',AI*10^6)
fprintf('AII  = %10.2f mm^2\n',AII*10^6)
fprintf('dpI  = %10.2f mm\n',dpI*1000)
fprintf('dpII = %10.2f mm\n',dpII*1000)
fprintf('csi  = %10.4f\n',csi)
fprintf('teta = %10.4f\n',teta)
%% grficos
figure(1)
plot(acel,FfImax,'r','LineWidth',2)
hold on
plot(acel,FfIImax,'b','LineWidth',2)
xlabel('desacelerao (m/s^2)')
ylabel('fora de frenagem (N)')
legend('dianteiro','traseiro')
grid on
%%
figure(2)
plot(ffII,FfIlim,'r','LineWidth',2)
hold on
plot(FfIIlim,ffI,'b','LineWidth',2)
hold on
plot(Ffr,Fff,'-ks','LineWidth',2)
xlabel('Fora no eixo traseiro (N)')
ylabel('Fora no eixo dianteiro (N)')
grid on
hold on
text(FfII,FfI,['\leftarrow \mu = ',num2str(mu)],'HorizontalAlignment','left')
%% FIM

